@@ -1,7 +1,7 @@
 test_that("An error is thrown if we forget various params", {
             
             expect_error(zzlite::zz_get(), "Whoops, seems like you forgot to pass an id!")
-            expect_error(zzlite::zz_get(id = 123), "Whoops, please let me know the format of the file I should get.")
+            expect_error(zzlite::zz_get(id = 123), "Whoops, please let me know the extension of the file I should get.")
 
           }
         )
\ No newline at end of file
